export default {
    "message": "Cannot use 'await' as identifier inside an async function",
    "column": 7,
    "index": 6,
    "lineNumber": 1
}
